# Политика выпуска

## Управление версиями

- Стабильные теги: `vX.Y.Z`
- Теги предварительной версии: `vX.Y.Z-rc.N`.

## Конвейер выпуска

1. Качественные ворота
2. Создание артефактов
3. Опубликовать PyPI
4. Создайте выпуск GitHub
5. Публикуйте документы при отправке на `main`.

## Список изменений

Создано на основе обычных коммитов и тщательно подобранных примечаний к выпуску.